@@ -1,7 +1,7 @@
 package WordList;
 
-our $DATE = '2018-04-02'; # DATE
-our $VERSION = '0.4.0'; # VERSION
+our $DATE = '2018-04-03'; # DATE
+our $VERSION = '0.4.1'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -109,7 +109,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.4.0 of WordList (from Perl distribution WordList), released on 2018-04-02.
+This document describes version 0.4.1 of WordList (from Perl distribution WordList), released on 2018-04-03.
 
 =head1 SYNOPSIS
 
@@ -142,9 +142,13 @@ C<frequency>).
 
 There must not be any duplicate entry in the word list.
 
-B<Dynamic wordlist.> A dynamic wordlist must set package variable C<$DYNAMIC> to
-true. A dynamic wordlist does not put the wordlist in the DATA section; instead,
-user relies on C<each_word()> or C<all_words()> to get the list.
+B<Dynamic and non-deterministic wordlist.> A dynamic wordlist must set package
+variable C<$DYNAMIC> to either 1 (deterministic) or 2 (non-deterministic). A
+dynamic wordlist does not put the wordlist in the DATA section; instead, user
+relies on C<each_word()> or C<all_words()> to get the list. A deterministic
+wordlist returns the same list everytime C<each_word()> or C<all_words()> is
+called. A non-deterministic list can return a different list for a different
+C<each_word()> or C<all_words()> call.
 
 =head1 DIFFERENCES WITH GAMES::WORD::WORDLIST
 
@@ -175,20 +179,6 @@ A couple of other functions might be added, with careful consideration.
 
 =back
 
-TODOS:
-
-=over
-
-=item * Interface for random pick from a subset
-
-Pick $n words of length $L.
-
-Pick $n words matching regex $re.
-
-=item * Interface to enable faster lookup/caching
-
-=back
-
 =head1 METHODS
 
 =head2 new
